clojure-lsp.feature.java-interop


ensure-java-class-members-analyzed!clj

(ensure-java-class-members-analyzed! db* full-class-name)

Analyze on demand the jar(s) defining full-class-name so its java member definitions become available for navigation/hover. No-op in eager/off mode or when already analyzed. Returns the current db value.

Analyze on demand the jar(s) defining `full-class-name` so its java member
definitions become available for navigation/hover. No-op in eager/off mode or
when already analyzed. Returns the current db value.
raw docstring

ensure-java-static-members-analyzed!clj

(ensure-java-static-members-analyzed! db* simple-class-name)

Analyze on demand the jar(s) defining classes whose simple name matches simple-class-name, used by java static-member completion. No-op in eager/off mode or when already analyzed. Returns the current db value.

Analyze on demand the jar(s) defining classes whose simple name matches
`simple-class-name`, used by java static-member completion. No-op in
eager/off mode or when already analyzed. Returns the current db value.
raw docstring

read-content!clj

(read-content! uri db producer)

retrieve-jdk-source-and-analyze!clj

(retrieve-jdk-source-and-analyze! db*)

Find JDK source and analyze it with clj-kondo for java class definitions.

If user has custom :jdk-source-uri, we don't try to find JDK source local or download it, we make sure zip is extracted otherwize extract it.

If no custom URI set, we try to find a local JDK source on Java instalation which is present most of the time and extract to global cache dir.

Otherwise, we download default OpenJDK source if setting is enabled.

Find JDK source and analyze it with clj-kondo for java class definitions.

If user has custom :jdk-source-uri, we don't try to find JDK source local
or download it, we make sure zip is extracted otherwize extract it.

If no custom URI set, we try to find a local JDK source on Java
instalation which is present most of the time and extract to global
cache dir.

Otherwise, we download default OpenJDK source if setting is enabled.
raw docstring

uri->translated-uriclj

(uri->translated-uri uri db producer)

cljdoc builds & hosts documentation for Clojure/Script libraries