clojure-lsp.kondo


canonicalize-java-analysisclj

(canonicalize-java-analysis analysis)

Canonicalizes java definition elements of a normalized analysis, sharing equal values in a single instance to reduce memory usage. Useful after reading analysis from the transit cache, which creates new instances even for equal values.

Canonicalizes java definition elements of a normalized analysis, sharing
equal values in a single instance to reduce memory usage. Useful after
reading analysis from the transit cache, which creates new instances even
for equal values.
raw docstring

clj-kondo-analysis-batch-sizeclj


clj-kondo-versionclj

(clj-kondo-version)

config-hashclj

(config-hash project-root)

db-with-analysisclj

(db-with-analysis db results)

Update db with normalized kondo analysis, replacing any existing analysis for the same uris.

Update `db` with normalized kondo analysis, replacing any existing analysis
for the same uris.
raw docstring

db-with-merged-analysisclj

(db-with-merged-analysis db results)

Like db-with-analysis but merges new buckets into the existing per-uri analysis instead of replacing it, so an additive pass (e.g. the lazy java-member-definitions analysis) keeps buckets already present at a uri such as java-class-definitions.

Like `db-with-analysis` but merges new buckets into the existing per-uri
analysis instead of replacing it, so an additive pass (e.g. the lazy
java-member-definitions analysis) keeps buckets already present at a uri such
as java-class-definitions.
raw docstring

db-with-resultsclj

(db-with-results db {:keys [findings config] :as results})

Update db with normalized kondo result.

Update `db` with normalized kondo result.
raw docstring

db-without-urisclj

(db-without-uris db uris)

Remove the given uris from the analysis, dep-graph, documents and kondo diagnostics, keeping the dep-graph in sync.

Remove the given `uris` from the analysis, dep-graph, documents and kondo
diagnostics, keeping the dep-graph in sync.
raw docstring

home-config-pathclj

(home-config-path)

lazy-java-member-definitions?clj

(lazy-java-member-definitions? db)

Whether external java member definitions are analyzed lazily (on demand) instead of up front during the classpath scan.

Whether external java member definitions are analyzed lazily (on demand)
instead of up front during the classpath scan.
raw docstring

logger-tagclj


project-config-pathclj

(project-config-path project-root-uri)

run-kondo-copy-configs!clj

(run-kondo-copy-configs! paths db)

run-kondo-on-jar-members!clj

(run-kondo-on-jar-members! jar-path db)

Analyze a single dependency jar-path for its java member definitions, used by the lazy/on-demand java analysis. Returns a normalized result keeping only the :java-member-definitions bucket (class definitions are already analyzed up front).

Analyze a single dependency `jar-path` for its java member definitions,
used by the lazy/on-demand java analysis. Returns a normalized result keeping
only the `:java-member-definitions` bucket (class definitions are already
analyzed up front).
raw docstring

run-kondo-on-jdk-source!clj

(run-kondo-on-jdk-source! paths db)

run-kondo-on-paths!clj

(run-kondo-on-paths! paths
                     db*
                     {:keys [external?] :as normalization-config}
                     file-analyzed-fn)

run-kondo-on-paths-batch!clj

(run-kondo-on-paths-batch! paths normalization-config file-analyzed-fn db*)

Run kondo on paths by partitioning the paths, with this we should call kondo more times but with fewer paths to analyze, improving memory.

Run kondo on paths by partitioning the paths, with this we should call
kondo more times but with fewer paths to analyze, improving memory.
raw docstring

run-kondo-on-reference-uris!clj

(run-kondo-on-reference-uris! uris db*)

run-kondo-on-text!clj

(run-kondo-on-text! text uri db*)

cljdoc builds & hosts documentation for Clojure/Script libraries